==> download.jqueryui.com-1.10.0pre.9.tgz: package/lib/themeroller.defaults.js <==
module.exports = {
	"bgColorDefault": "e6e6e6",
	"borderColorDefault": "d3d3d3",
	"fcDefault": "555555",

	"bgColorHover": "dadada",
	"borderColorHover": "999999",
	"fcHover": "212121",

	"bgColorActive": "ffffff",
	"borderColorActive": "aaaaaa",
	"fcActive": "212121",

	"bgColorHeader": "cccccc",
	"borderColorHeader": "aaaaaa",
	"fcHeader": "222222",

	"bgColorContent": "ffffff",
	"borderColorContent": "aaaaaa",
	"fcContent": "222222",

	"bgColorHighlight": "fbf9ee",
	"borderColorHighlight": "fcefa1",
	"fcHighlight": "363636",

	"bgColorError": "fef1ec",
	"borderColorError": "cd0a0a",
	"fcError": "cd0a0a",

	"bgColorOverlay": "aaaaaa",
	"opacityOverlay": "30",

	"bgColorShadow": "aaaaaa",
	"opacityShadow": "30",
	"offsetTopShadow": "-8px",
	"offsetLeftShadow": "-8px",
	"thicknessShadow": "8px",
	"cornerRadiusShadow": "8px",

	"fsDefault": "1.1em",
	"ffDefault": "Verdana,Arial,sans-serif",
	"fwDefault": "normal",
	"cornerRadius": "4px",

	"bgTextureDefault": "02_glass.png",
	"bgTextureHover": "02_glass.png",
	"bgTextureActive": "02_glass.png",
	"bgTextureHeader": "03_highlight_soft.png",
	"bgTextureContent": "01_flat.png",
	"bgTextureHighlight": "02_glass.png",
	"bgTextureError": "02_glass.png",
	"bgTextureOverlay": "01_flat.png",
	"bgTextureShadow": "01_flat.png",

	"bgImgOpacityDefault": "75",
	"bgImgOpacityHover": "75",
	"bgImgOpacityActive": "65",
	"bgImgOpacityHeader": "75",
	"bgImgOpacityContent": "75",
	"bgImgOpacityHighlight": "55",
	"bgImgOpacityError": "95",
	"bgImgOpacityOverlay": "0",
	"bgImgOpacityShadow": "0",

	"iconColorActive": "454545",
	"iconColorContent": "222222",
	"iconColorDefault": "888888",
	"iconColorError": "cd0a0a",
	"iconColorHeader": "222222",
	"iconColorHighlight": "2e83ff",
	"iconColorHover": "454545"
};

==> download.jqueryui.com-1.10.0-17.tgz: package/lib/themeroller.defaults.js <==
module.exports = {
	"bgColorDefault": "e6e6e6",
	"borderColorDefault": "d3d3d3",
	"fcDefault": "555555",

	"bgColorHover": "dadada",
	"borderColorHover": "999999",
	"fcHover": "212121",

	"bgColorActive": "ffffff",
	"borderColorActive": "aaaaaa",
	"fcActive": "212121",

	"bgColorHeader": "cccccc",
	"borderColorHeader": "aaaaaa",
	"fcHeader": "222222",

	"bgColorContent": "ffffff",
	"borderColorContent": "aaaaaa",
	"fcContent": "222222",

	"bgColorHighlight": "fbf9ee",
	"borderColorHighlight": "fcefa1",
	"fcHighlight": "363636",

	"bgColorError": "fef1ec",
	"borderColorError": "cd0a0a",
	"fcError": "cd0a0a",

	"bgColorOverlay": "aaaaaa",
	"opacityOverlay": "30",

	"bgColorShadow": "aaaaaa",
	"opacityShadow": "30",
	"offsetTopShadow": "-8px",
	"offsetLeftShadow": "-8px",
	"thicknessShadow": "8px",
	"cornerRadiusShadow": "8px",

	"fsDefault": "1.1em",
	"ffDefault": "Verdana,Arial,sans-serif",
	"fwDefault": "normal",
	"cornerRadius": "4px",

	"bgTextureDefault": "glass",
	"bgTextureHover": "glass",
	"bgTextureActive": "glass",
	"bgTextureHeader": "highlight_soft",
	"bgTextureContent": "flat",
	"bgTextureHighlight": "glass",
	"bgTextureError": "glass",
	"bgTextureOverlay": "flat",
	"bgTextureShadow": "flat",

	"bgImgOpacityDefault": "75",
	"bgImgOpacityHover": "75",
	"bgImgOpacityActive": "65",
	"bgImgOpacityHeader": "75",
	"bgImgOpacityContent": "75",
	"bgImgOpacityHighlight": "55",
	"bgImgOpacityError": "95",
	"bgImgOpacityOverlay": "0",
	"bgImgOpacityShadow": "0",

	"iconColorActive": "454545",
	"iconColorContent": "222222",
	"iconColorDefault": "888888",
	"iconColorError": "cd0a0a",
	"iconColorHeader": "222222",
	"iconColorHighlight": "2e83ff",
	"iconColorHover": "454545"
};
